nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Wcr

Struct Wcr 

#[repr(transparent)]
pub struct Wcr(pub u16);
Watchdog Control Register

Tuple Fields

0: u16

Implementations

Source

impl Wcr

pub const fn wdzst(&self) -> Wdzst

WDZST

pub const fn set_wdzst(&mut self, val: Wdzst)

WDZST

pub const fn wdbg(&self) -> Wdbg

WDBG

pub const fn set_wdbg(&mut self, val: Wdbg)

WDBG

pub const fn wde(&self) -> Wde

WDE

pub const fn set_wde(&mut self, val: Wde)

WDE

pub const fn wdt(&self) -> Wdt

WDT

pub const fn set_wdt(&mut self, val: Wdt)

WDT

pub const fn srs(&self) -> Srs

SRS

pub const fn set_srs(&mut self, val: Srs)

SRS

pub const fn wda(&self) -> Wda

WDA

pub const fn set_wda(&mut self, val: Wda)

WDA

pub const fn sre(&self) -> Sre

Software Reset Extension, an optional way to generate software reset

pub const fn set_sre(&mut self, val: Sre)

Software Reset Extension, an optional way to generate software reset

pub const fn wdw(&self) -> Wdw

WDW

pub const fn set_wdw(&mut self, val: Wdw)

WDW

pub const fn wt(&self) -> Wt

WT

pub const fn set_wt(&mut self, val: Wt)

WT